.. _libdoc_tensor_nnet_batchnorm:

=======================================
:mod:`batchnorm` -- Batch Normalization
=======================================

.. module:: tensor.nnet.batchnorm
   :platform: Unix, Windows
   :synopsis: Batch Normalization
.. moduleauthor:: LISA


.. autofunction:: aesara.tensor.nnet.batchnorm.batch_normalization_train
.. autofunction:: aesara.tensor.nnet.batchnorm.batch_normalization_test

.. seealso:: cuDNN batch normalization: :class:`aesara.gpuarray.dnn.dnn_batch_normalization_train`, :class:`aesara.gpuarray.dnn.dnn_batch_normalization_test>`.

.. autofunction:: aesara.tensor.nnet.batchnorm.batch_normalization
